SimpleWWTHandler
================

.. currentmodule:: toasty.viewer

.. autoclass:: SimpleWWTHandler
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~SimpleWWTHandler.wtml

   .. rubric:: Methods Summary

   .. autosummary::

      ~SimpleWWTHandler.send_head
      ~SimpleWWTHandler.serve_string

   .. rubric:: Attributes Documentation

   .. autoattribute:: wtml

   .. rubric:: Methods Documentation

   .. automethod:: send_head
   .. automethod:: serve_string
